@@ -1,9 +1,9 @@
 package Sim::OPT::Descend;
-# Copyright (C) 2008-2022 by Gian Luca Brunetti and Politecnico di Milano.
+# Copyright (C) 2008-2025 by Gian Luca Brunetti and Politecnico di Milano.
 # This is the module Sim::OPT::Descend of Sim::OPT, a program for detailed metadesign managing parametric explorations through the ESP-r building performance simulation platform and performing optimization by block coordinate descent.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
-use v5.14;
+# use v5.14;
 # use v5.20;
 
 use Exporter;
@@ -39,7 +39,7 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend prepareblank tee ); # our @EXPORT = qw( );
 
-$VERSION = '0.165'; # our $VERSION = '';
+$VERSION = '0.167'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -952,7 +952,7 @@ sub descend
         my @blockelts = @{ $blockelts_r };
         foreach my $key ( sort ( keys %varns ) )
         {
-          if ( not( $key ~~ @blockelts ) )
+          if ( not( grep { $_ eq $key } @blockelts ) )
           {
             $varns{$key} = 1;
           }
@@ -990,7 +990,7 @@ sub descend
         {
           foreach my $key ( sort ( keys( %varnums ) ) )
           {
-            if ( not( $key ~~ @blockelts ) )
+            if ( not( grep { $_ eq $key } @blockelts ) )
             {
               $modhs{$key} = $varnums{$key};
               $torecovers{$key} = $carrier{$key};
@@ -1504,7 +1504,7 @@ sub descend
           my $c = 0;
           foreach my $instance ( @{ $vehicles{cumulateall} } )
           {
-            if ( $instance->{is} ~~ @reds )
+            if ( grep { $_ eq $instance->{is} } @reds )
             {
               my @instancees;
               push( @instancees, $instance );
@@ -1660,7 +1660,7 @@ sub descend
           my $c = 0;
           foreach my $instance ( @{ $vehicles{cumulateall} } )
           {
-            if ( $instance->{is} ~~ @reds )
+            if ( grep { $_ eq $instance->{is} } @reds )
             {
               my @instancees;
               push( @instancees, $instance );
